@@ -274,7 +274,7 @@ public:
 	    // dallocateA_dist(n, nnz, &a, &asub, &xa);
 	    // dCompRow_to_CompCol_dist(m,n,nnz,arow,asubrow,xarow,&a,&asub,&xa);
 	    
-	    CompRow_to_CompCol_dist(m,n,nnz,AA.a,AA.cl,AA.lg,&a,&asub,&xa);
+	    this->CompRow_to_CompCol_dist(m,n,nnz,AA.a,AA.cl,AA.lg,&a,&asub,&xa);
 	  
 	    /* Broadcast matrix A to the other PEs. */
 	    MPI_Bcast( &m,   1,   mpi_int_t,  0, grid.comm );
@@ -295,7 +295,7 @@ public:
 	    MPI_Bcast( &nnz, 1,   mpi_int_t,  0, grid.comm );
 	    
 	    /* Allocate storage for compressed column representation. */
-	    zallocateA_dist(n, nnz, dc(&a), &asub, &xa);
+	    zallocateA_dist(n, nnz, this->dc(&a), &asub, &xa);
 	    
 	    MPI_Bcast( a, nnz, SuperLU_MPI_DOUBLE_COMPLEX, 0, grid.comm );
 	    MPI_Bcast( asub, nnz, mpi_int_t,  0, grid.comm );
@@ -306,7 +306,7 @@ public:
 	  Dtype_t R_SLU = SuperLUmpiDISTDriver<R>::R_SLU_T(); 
 	  
 	  cout << "Debut: Create_CompCol_Matrix_dist" <<endl;
-	  Create_CompCol_Matrix_dist(&A, m, n, nnz, a, asub, xa, SLU_NC, R_SLU, SLU_GE);      
+	  this->Create_CompCol_Matrix_dist(&A, m, n, nnz, a, asub, xa, SLU_NC, R_SLU, SLU_GE);      
 	  cout << "Fin: Create_CompCol_Matrix_dist" <<endl;
 	  /* creation of pseudo solution + second member */
 	  
@@ -411,7 +411,7 @@ public:
 	     MPI_Bcast( &nnz, 1,   mpi_int_t,  0, grid.comm );
 	     
 	     /* Allocate storage for compressed column representation. */
-	     zallocateA_dist(n, nnz, dc(&a), &asub, &xa);
+	     zallocateA_dist(n, nnz, this->dc(&a), &asub, &xa);
 	     
 	     MPI_Bcast( a, nnz, SuperLU_MPI_DOUBLE_COMPLEX, 0, grid.comm );
 	     MPI_Bcast( asub, nnz, mpi_int_t,  0, grid.comm );
@@ -433,7 +433,7 @@ public:
 	   fst_row = iam * m_loc_fst;
 	   
 	   nnz_loc = xa[fst_row+m_loc]-xa[fst_row];
-	   zallocateA_dist(m_loc, nnz_loc, dc(&aloc), &asubloc, &xaloc);
+	   zallocateA_dist(m_loc, nnz_loc, this->dc(&aloc), &asubloc, &xaloc);
 	   
 	   //xaloc = (int_t*) intMalloc_dist(m_loc+1);
 	   for(int ii=0; ii < m_loc; ii++){
@@ -461,7 +461,7 @@ public:
 	   Dtype_t R_SLU = SuperLUmpiDISTDriver<R>::R_SLU_T(); 
 	   
 	   if(verbosity) cout << "Debut: Create_CompRowCol_Matrix_dist" <<endl;
-	   if(verbosity) Create_CompRowLoc_Matrix_dist(&A, m, n, nnz_loc, m_loc, fst_row, aloc, asubloc, xaloc, SLU_NR_loc, R_SLU, SLU_GE);
+	   if(verbosity) this->Create_CompRowLoc_Matrix_dist(&A, m, n, nnz_loc, m_loc, fst_row, aloc, asubloc, xaloc, SLU_NR_loc, R_SLU, SLU_GE);
 	   
 	   cout << "Fin: Create_CompRowCol_Matrix_dist" <<endl;
 	   /* creation of pseudo solution + second member */
